==> ejc-assistrmat-impl-3.0.0-20220322.020504-1-sources.jar: com/ejianc/business/assist/ownrmat/bean/HandleDetailEntity.java <==
package com.ejianc.business.assist.ownrmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 周转材处置明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proownrmat_handle_detail")
public class HandleDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="handle_id")
    private Long handleId; // 处置ID
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类Id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private Long unit; // 计量单位
    @TableField(value="unit_name")
    private String unitName; // 计量单位
    @TableField(value="surplus_num")
    private BigDecimal surplusNum; // 库存余量
    @TableField(value="handle_price")
    private BigDecimal handlePrice; // 处置单价
    @TableField(value="handle_num")
    private BigDecimal handleNum; // 处置数量
    @TableField(value="handle_mny")
    private BigDecimal handleMny; // 处置金额（无税）
    @TableField(value="tax")
    private BigDecimal tax; // 处置税额
    @TableField(value="handle_sub_tax_mny")
    private BigDecimal handleSubTaxMny; // 处置差额
    @TableField(value="handle_sub_mny")
    private BigDecimal handleSubMny; // 处置差额(无税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="handle_tax_price")
    private BigDecimal handleTaxPrice; // 处置单价(含税)
    @TableField(value="net_worth_tax_mny")
    private BigDecimal netWorthTaxMny; // 材料净值(含税)
    @TableField(value="residual_value_tax_mny")
    private BigDecimal residualValueTaxMny; // 材料残值(含税)
    @TableField(value="net_worth_mny")
    private BigDecimal netWorthMny; // 材料净值(无税)
    @TableField(value="residual_value_mny")
    private BigDecimal residualValueMny; // 材料残值(无税)
    @TableField(value="residual_value_rate")
    private BigDecimal residualValueRate; // 残值率
    @TableField(value="original_value_tax_price")
    private BigDecimal originalValueTaxPrice; // 原值单价(含税)
    @TableField(value="original_value_price")
    private BigDecimal originalValuePrice; // 原值单价(无税)
    @TableField(value="original_value_tax_mny")
    private BigDecimal originalValueTaxMny; // 材料原值(含税)
    @TableField(value="original_value_mny")
    private BigDecimal originalValueMny; // 材料原值(无税)
    @TableField(value="on_hand_num")
    private BigDecimal onHandNum; // 在场数量
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="handle_tax_mny")
    private BigDecimal handleTaxMny; // 处置金额
    

    public Long getHandleId() {
        return handleId;
    }

    public void setHandleId(Long handleId) {
        this.handleId = handleId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnit() {
        return unit;
    }

    public void setUnit(Long unit) {
        this.unit = unit;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getHandlePrice() {
        return handlePrice;
    }

    public void setHandlePrice(BigDecimal handlePrice) {
        this.handlePrice = handlePrice;
    }
    public BigDecimal getHandleNum() {
        return handleNum;
    }

    public void setHandleNum(BigDecimal handleNum) {
        this.handleNum = handleNum;
    }
    public BigDecimal getHandleMny() {
        return handleMny;
    }

    public void setHandleMny(BigDecimal handleMny) {
        this.handleMny = handleMny;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }

    public BigDecimal getHandleSubTaxMny() {
        return handleSubTaxMny;
    }

    public void setHandleSubTaxMny(BigDecimal handleSubTaxMny) {
        this.handleSubTaxMny = handleSubTaxMny;
    }
    public BigDecimal getHandleSubMny() {
        return handleSubMny;
    }

    public void setHandleSubMny(BigDecimal handleSubMny) {
        this.handleSubMny = handleSubMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getHandleTaxPrice() {
        return handleTaxPrice;
    }

    public void setHandleTaxPrice(BigDecimal handleTaxPrice) {
        this.handleTaxPrice = handleTaxPrice;
    }

    public BigDecimal getNetWorthTaxMny() {
        return netWorthTaxMny;
    }

    public void setNetWorthTaxMny(BigDecimal netWorthTaxMny) {
        this.netWorthTaxMny = netWorthTaxMny;
    }

    public BigDecimal getResidualValueTaxMny() {
        return residualValueTaxMny;
    }

    public void setResidualValueTaxMny(BigDecimal residualValueTaxMny) {
        this.residualValueTaxMny = residualValueTaxMny;
    }

    public BigDecimal getNetWorthMny() {
        return netWorthMny;
    }

    public void setNetWorthMny(BigDecimal netWorthMny) {
        this.netWorthMny = netWorthMny;
    }

    public BigDecimal getResidualValueMny() {
        return residualValueMny;
    }

    public void setResidualValueMny(BigDecimal residualValueMny) {
        this.residualValueMny = residualValueMny;
    }

    public BigDecimal getResidualValueRate() {
        return residualValueRate;
    }

    public void setResidualValueRate(BigDecimal residualValueRate) {
        this.residualValueRate = residualValueRate;
    }

    public BigDecimal getOriginalValueTaxPrice() {
        return originalValueTaxPrice;
    }

    public void setOriginalValueTaxPrice(BigDecimal originalValueTaxPrice) {
        this.originalValueTaxPrice = originalValueTaxPrice;
    }

    public BigDecimal getOriginalValuePrice() {
        return originalValuePrice;
    }

    public void setOriginalValuePrice(BigDecimal originalValuePrice) {
        this.originalValuePrice = originalValuePrice;
    }

    public BigDecimal getOriginalValueTaxMny() {
        return originalValueTaxMny;
    }

    public void setOriginalValueTaxMny(BigDecimal originalValueTaxMny) {
        this.originalValueTaxMny = originalValueTaxMny;
    }

    public BigDecimal getOriginalValueMny() {
        return originalValueMny;
    }

    public void setOriginalValueMny(BigDecimal originalValueMny) {
        this.originalValueMny = originalValueMny;
    }

    public BigDecimal getOnHandNum() {
        return onHandNum;
    }

    public void setOnHandNum(BigDecimal onHandNum) {
        this.onHandNum = onHandNum;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getHandleTaxMny() {
        return handleTaxMny;
    }

    public void setHandleTaxMny(BigDecimal handleTaxMny) {
        this.handleTaxMny = handleTaxMny;
    }
}

==> ejc-assistrmat-impl-3.0.0-20220323.064606-11-sources.jar: com/ejianc/business/assist/ownrmat/bean/HandleDetailEntity.java <==
package com.ejianc.business.assist.ownrmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 周转材处置明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistownrmat_handle_detail")
public class HandleDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="handle_id")
    private Long handleId; // 处置ID
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类Id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private Long unit; // 计量单位
    @TableField(value="unit_name")
    private String unitName; // 计量单位
    @TableField(value="surplus_num")
    private BigDecimal surplusNum; // 库存余量
    @TableField(value="handle_price")
    private BigDecimal handlePrice; // 处置单价
    @TableField(value="handle_num")
    private BigDecimal handleNum; // 处置数量
    @TableField(value="handle_mny")
    private BigDecimal handleMny; // 处置金额（无税）
    @TableField(value="tax")
    private BigDecimal tax; // 处置税额
    @TableField(value="handle_sub_tax_mny")
    private BigDecimal handleSubTaxMny; // 处置差额
    @TableField(value="handle_sub_mny")
    private BigDecimal handleSubMny; // 处置差额(无税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="handle_tax_price")
    private BigDecimal handleTaxPrice; // 处置单价(含税)
    @TableField(value="net_worth_tax_mny")
    private BigDecimal netWorthTaxMny; // 材料净值(含税)
    @TableField(value="residual_value_tax_mny")
    private BigDecimal residualValueTaxMny; // 材料残值(含税)
    @TableField(value="net_worth_mny")
    private BigDecimal netWorthMny; // 材料净值(无税)
    @TableField(value="residual_value_mny")
    private BigDecimal residualValueMny; // 材料残值(无税)
    @TableField(value="residual_value_rate")
    private BigDecimal residualValueRate; // 残值率
    @TableField(value="original_value_tax_price")
    private BigDecimal originalValueTaxPrice; // 原值单价(含税)
    @TableField(value="original_value_price")
    private BigDecimal originalValuePrice; // 原值单价(无税)
    @TableField(value="original_value_tax_mny")
    private BigDecimal originalValueTaxMny; // 材料原值(含税)
    @TableField(value="original_value_mny")
    private BigDecimal originalValueMny; // 材料原值(无税)
    @TableField(value="on_hand_num")
    private BigDecimal onHandNum; // 在场数量
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="handle_tax_mny")
    private BigDecimal handleTaxMny; // 处置金额
    

    public Long getHandleId() {
        return handleId;
    }

    public void setHandleId(Long handleId) {
        this.handleId = handleId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnit() {
        return unit;
    }

    public void setUnit(Long unit) {
        this.unit = unit;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getHandlePrice() {
        return handlePrice;
    }

    public void setHandlePrice(BigDecimal handlePrice) {
        this.handlePrice = handlePrice;
    }
    public BigDecimal getHandleNum() {
        return handleNum;
    }

    public void setHandleNum(BigDecimal handleNum) {
        this.handleNum = handleNum;
    }
    public BigDecimal getHandleMny() {
        return handleMny;
    }

    public void setHandleMny(BigDecimal handleMny) {
        this.handleMny = handleMny;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }

    public BigDecimal getHandleSubTaxMny() {
        return handleSubTaxMny;
    }

    public void setHandleSubTaxMny(BigDecimal handleSubTaxMny) {
        this.handleSubTaxMny = handleSubTaxMny;
    }
    public BigDecimal getHandleSubMny() {
        return handleSubMny;
    }

    public void setHandleSubMny(BigDecimal handleSubMny) {
        this.handleSubMny = handleSubMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getHandleTaxPrice() {
        return handleTaxPrice;
    }

    public void setHandleTaxPrice(BigDecimal handleTaxPrice) {
        this.handleTaxPrice = handleTaxPrice;
    }

    public BigDecimal getNetWorthTaxMny() {
        return netWorthTaxMny;
    }

    public void setNetWorthTaxMny(BigDecimal netWorthTaxMny) {
        this.netWorthTaxMny = netWorthTaxMny;
    }

    public BigDecimal getResidualValueTaxMny() {
        return residualValueTaxMny;
    }

    public void setResidualValueTaxMny(BigDecimal residualValueTaxMny) {
        this.residualValueTaxMny = residualValueTaxMny;
    }

    public BigDecimal getNetWorthMny() {
        return netWorthMny;
    }

    public void setNetWorthMny(BigDecimal netWorthMny) {
        this.netWorthMny = netWorthMny;
    }

    public BigDecimal getResidualValueMny() {
        return residualValueMny;
    }

    public void setResidualValueMny(BigDecimal residualValueMny) {
        this.residualValueMny = residualValueMny;
    }

    public BigDecimal getResidualValueRate() {
        return residualValueRate;
    }

    public void setResidualValueRate(BigDecimal residualValueRate) {
        this.residualValueRate = residualValueRate;
    }

    public BigDecimal getOriginalValueTaxPrice() {
        return originalValueTaxPrice;
    }

    public void setOriginalValueTaxPrice(BigDecimal originalValueTaxPrice) {
        this.originalValueTaxPrice = originalValueTaxPrice;
    }

    public BigDecimal getOriginalValuePrice() {
        return originalValuePrice;
    }

    public void setOriginalValuePrice(BigDecimal originalValuePrice) {
        this.originalValuePrice = originalValuePrice;
    }

    public BigDecimal getOriginalValueTaxMny() {
        return originalValueTaxMny;
    }

    public void setOriginalValueTaxMny(BigDecimal originalValueTaxMny) {
        this.originalValueTaxMny = originalValueTaxMny;
    }

    public BigDecimal getOriginalValueMny() {
        return originalValueMny;
    }

    public void setOriginalValueMny(BigDecimal originalValueMny) {
        this.originalValueMny = originalValueMny;
    }

    public BigDecimal getOnHandNum() {
        return onHandNum;
    }

    public void setOnHandNum(BigDecimal onHandNum) {
        this.onHandNum = onHandNum;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getHandleTaxMny() {
        return handleTaxMny;
    }

    public void setHandleTaxMny(BigDecimal handleTaxMny) {
        this.handleTaxMny = handleTaxMny;
    }
}
